@@ -32,12 +32,12 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "camel-url.h"
 #include "camel-exception.h"
+#include "camel-i18n.h"
 #include "camel-mime-utils.h"
 #include "camel-object.h"
 #include "camel-string-utils.h"
-#include "camel-i18n.h"
+#include "camel-url.h"
 
 static void copy_param (GQuark key_id, gpointer data, gpointer user_data);
 static void output_param (GQuark key_id, gpointer data, gpointer user_data);
@@ -57,10 +57,12 @@ CamelURL *
 camel_url_new_with_base (CamelURL *base, const char *url_string)
 {
 	CamelURL *url;
+	const char *start;
 	const char *end, *hash, *colon, *semi, *at, *slash, *question;
 	const char *p;
 
 	url = g_new0 (CamelURL, 1);
+	start = url_string;
 
 	/* See RFC1808 for details. IF YOU CHANGE ANYTHING IN THIS
 	 * FUNCTION, RUN tests/misc/url AFTERWARDS.
@@ -91,6 +93,13 @@ camel_url_new_with_base (CamelURL *base, const char *url_string)
 	if (!*url_string && !base)
 		return url;
 
+#ifdef G_OS_WIN32
+	if (url->protocol && !strcmp(url->protocol, "file")) {
+		url->path = g_filename_from_uri(start, &url->host, NULL);
+		return url;
+	}
+#endif
+
 	/* Check for authority */
 	if (strncmp (url_string, "//", 2) == 0) {
 		url_string += 2;
@@ -110,7 +119,7 @@ camel_url_new_with_base (CamelURL *base, const char *url_string)
 
 			semi = strchr(url_string, ';');
 			if (semi && semi < colon &&
-			    !strncasecmp (semi, ";auth=", 6)) {
+			    !g_ascii_strncasecmp (semi, ";auth=", 6)) {
 				url->authmech = g_strndup (semi + 6,
 							   colon - semi - 6);
 				camel_url_decode (url->authmech);
@@ -316,6 +325,11 @@ camel_url_to_string (CamelURL *url, guint32 flags)
 	 * tests/misc/url AFTERWARD.
 	 */
 	
+#ifdef G_OS_WIN32
+	if (url->protocol && !strcmp(url->protocol, "file"))
+		return g_filename_to_uri(url->path, url->host, NULL);
+#endif G_OS_WIN32
+	
 	str = g_string_sized_new (20);
 	
 	if (url->protocol)
@@ -705,3 +719,33 @@ camel_url_copy(const CamelURL *in)
 
 	return out;
 }
+
+char *
+camel_url_decode_path (const char *path)
+{
+        gchar **comps;
+        char *new_path = NULL;
+        GString *str;
+        int i = 0;
+
+        if (!path)
+                return g_strdup("");    /* ??? or NULL? */
+
+        str = g_string_new (NULL);
+
+        comps = g_strsplit (path, "/", -1);
+        while (comps[i]) {
+                camel_url_decode (comps[i]);
+                g_string_append (str, comps[i]);
+                g_string_append_c (str, '/');
+                i++;
+        }
+
+        /* Strip-off the trailing "/" */
+        new_path = g_strndup (str->str, str->len-1);
+
+        g_strfreev (comps);
+        g_string_free (str, TRUE);
+
+        return new_path;
+}
